@@ -3,9 +3,9 @@ package declaration
 """
 __title__ = 'meo'
 __description__ = 'frequently-used function library'
-__version__ = '0.0.5.2022.8.13'
+__version__ = '0.0.8'
 __url__ = "http://github.com/miaobuao/meo"
 __author__ = 'miaobuao'
-__author_email__ = '617802189@qq.com'
+__author_email__ = 'miaobuao@outlook.com'
 __license__ = 'MIT License'
 __copyright__ = 'Copyright 2022 miaobuao'
